@@ -33,7 +33,7 @@ class User(Base):
 
     def __repr__(self):
         return '<User {} (id={})>'.format(self, self.id)
-    
+
     def __str__(self):
         return self.username
 
@@ -67,19 +67,23 @@ class Student(Base):
     stage = relationship('Stage')
 
     # Уровень обучения
-    edu_level_id = Column('edu_levels_id', ForeignKey('univer_edu_levels.edu_level_id'))
+    edu_level_id = Column('edu_levels_id', ForeignKey(
+        'univer_edu_levels.edu_level_id'))
     edu_level = relationship('EduLevel')
 
     # Форма обучения
-    education_form_id = Column(ForeignKey('univer_education_form.education_form_id'))
+    education_form_id = Column(ForeignKey(
+        'univer_education_form.education_form_id'))
     education_form = relationship('EducationForm')
 
     # Тип поступления
-    enrollment_type_id = Column(ForeignKey('univer_enrollment_type.enrollment_type_id'))
+    enrollment_type_id = Column(ForeignKey(
+        'univer_enrollment_type.enrollment_type_id'))
     enrollment_type = relationship('EnrollmentType')
 
     # Тип оплаты
-    payment_form_id = Column('payment_forms_id', ForeignKey('univer_payment_forms.payment_form_id'))
+    payment_form_id = Column('payment_forms_id', ForeignKey(
+        'univer_payment_forms.payment_form_id'))
     payment_form = relationship('PaymentForm')
 
     country_id = Column(ForeignKey('univer_country.country_id'))
@@ -101,17 +105,20 @@ class Student(Base):
     # ФИО студента в дательном падеже (На русском языке)
     dative_last_name_ru = Column('students_dative_sname_ru', String(100))
     dative_first_name_ru = Column('students_dative_name_ru', String(100))
-    dative_middle_name_ru = Column('students_dative_father_name_ru', String(100))
+    dative_middle_name_ru = Column(
+        'students_dative_father_name_ru', String(100))
 
     # ФИО студента в дательном падеже (На казахском языке)
     dative_last_name_kz = Column('students_dative_sname_kz', String(100))
     dative_first_name_kz = Column('students_dative_name_kz', String(100))
-    dative_middle_name_kz = Column('students_dative_father_name_kz', String(100))
+    dative_middle_name_kz = Column(
+        'students_dative_father_name_kz', String(100))
 
     # ФИО студента в дательном падеже (На английском языке)
     dative_last_name_en = Column('students_dative_sname_en', String(100))
     dative_first_name_en = Column('students_dative_name_en', String(100))
-    dative_middle_name_en = Column('students_dative_father_name_en', String(100))
+    dative_middle_name_en = Column(
+        'students_dative_father_name_en', String(100))
 
     # Фамилия и Имя студента транслитом
     last_name_translit = Column('students_sname_intern', String(100))
@@ -124,17 +131,22 @@ class Student(Base):
     course = Column('students_curce_number', Integer)
 
     # Документ
-    document_identity_type_id = Column('students_document_identity_type', ForeignKey('univer_document_identity.document_identity_type'))
+    document_identity_type_id = Column('students_document_identity_type', ForeignKey(
+        'univer_document_identity.document_identity_type'))
     document_identity_type = relationship('DocumentIdentity')
-    document_identity_number = Column('students_document_identity_number', String(50))
-    document_identity_date = Column('students_document_identity_date', DateTime)
-    document_identity_issued = Column('students_document_identity_issued', String(100))
+    document_identity_number = Column(
+        'students_document_identity_number', String(50))
+    document_identity_date = Column(
+        'students_document_identity_date', DateTime)
+    document_identity_issued = Column(
+        'students_document_identity_issued', String(100))
 
     # ИИН студента
     identify_code = Column('students_identify_code', String(50))
 
     # Данные об окончании учебного заведения перед поступлением в университет
-    graduate_info_id = Column(ForeignKey('univer_graduate_info.graduate_info_id'))
+    graduate_info_id = Column(ForeignKey(
+        'univer_graduate_info.graduate_info_id'))
     graduate_info = relationship('GraduateInfo')
 
     # Факультет
@@ -149,7 +161,8 @@ class Student(Base):
     educ_plan_adm_year = Column(Integer)
 
     # Языковое отделение
-    lang_division_id = Column(ForeignKey('univer_lang_division.lang_division_id'))
+    lang_division_id = Column(ForeignKey(
+        'univer_lang_division.lang_division_id'))
     lang_division = relationship('LangDivision')
 
     # Нуждается в общежитии
@@ -162,7 +175,6 @@ class Student(Base):
         elif self.payment_form_id == 5:
             return 'на основе государственного образовательного гранта'
 
-
     @property
     def payment_info_kz(self):
         if self.payment_form_id == 2:
@@ -170,7 +182,6 @@ class Student(Base):
         elif self.payment_form_id == 5:
             return 'мемлекеттік білім беру гранты негізінде'
 
-
     @property
     def edu_level_info_ru(self):
         if self.edu_level_id == 1:
@@ -180,7 +191,6 @@ class Student(Base):
         elif self.edu_level_id == 2:
             return 'по сокращенной образовательной программе на базе высшего образования'
 
-
     @property
     def edu_level_info_kz(self):
         if self.edu_level_id == 1:
@@ -190,7 +200,6 @@ class Student(Base):
         elif self.edu_level_id == 2:
             return 'жоғары білім негізінде қысқартылған білім беру бағдарламасы бойынша күндізгі білім беру нысаны'
 
-
     @property
     def dative_full_name_ru(self):
         dative_last_name_ru = self.dative_last_name_ru if self.dative_last_name_ru else self.last_name
@@ -213,7 +222,7 @@ class Student(Base):
 
     def __repr__(self):
         return '<Student {} (id={} user={} status={})>'.format(self, self.id, self.user_id, self.status)
-    
+
     def __str__(self):
         return ' '.join(filter(None, [self.last_name, self.first_name, self.middle_name]))
 
@@ -253,7 +262,7 @@ class Personnel(Base):
 
     def __repr__(self):
         return '<Personnel {} (id={} user={} status={})>'.format(self, self.user_id, self.status)
-    
+
     def __str__(self):
         return ' '.join(filter(None, [self.last_name, self.first_name, self.middle_name]))
 
@@ -270,7 +279,8 @@ class Teacher(Base):
     id = Column('teacher_id', Integer, primary_key=True)
 
     # Сотрудник
-    personnel_id = Column('personal_id', ForeignKey('univer_personal.personal_id'))
+    personnel_id = Column('personal_id', ForeignKey(
+        'univer_personal.personal_id'))
     personnel = relationship('Personnel')
 
     # Статус
@@ -278,6 +288,38 @@ class Teacher(Base):
 
     def __repr__(self):
         return '<Teacher {} (id={} personnel={} status={})>'.format(self, self.id, self.personnel_id, self.status)
-    
+
     def __str__(self):
-        return str(self.personnel)
\ No newline at end of file
+        return str(self.personnel)
+
+
+class OfficeRegistrator(Base):
+    """
+    Модель "Сотрудник Офис-Регистратора"
+    """
+
+    __tablename__ = 'univer_office_registrator'
+
+    # Идентификатор
+    id = Column('office_registrator_id', Integer, primary_key=True)
+
+    # Сотрудник
+    personnel_id = Column('personal_id', ForeignKey(
+        'univer_personal.personal_id'))
+    personnel = relationship('Personnel')
+
+    # Факультет
+    faculty_id = Column(ForeignKey('univer_faculty.faculty_id'))
+    faculty = relationship('Faculty')
+
+    # Статус
+    status = Column(Integer)
+
+    # Тип
+    type = Column(Integer)
+
+    def __repr__(self):
+        return '<OfficeRegistrator {} (id={})>'.format(self, self.id)
+
+    def __str__(self):
+        return str(self.personnel)
